@@ -3,10 +3,12 @@ set -e
 OLD_PWD=$(pwd)
 cd "$(dirname "$0")"
 
+DISTRI=debian11
+
 # Build docker image
-IMAGE=remiangenieux/test-bashckup:debian
+IMAGE=remiangenieux/test-bashckup:$DISTRI
 CONTAINER_NAME=test-bashckup
-docker build -t "$IMAGE" ./images/debian
+docker build -t "$IMAGE" ./images -f images/$DISTRI/Dockerfile
 docker push "$IMAGE"
 
 # Create container
@@ -15,11 +17,11 @@ docker cp ../. "$CONTAINER_NAME":/opt
 set +e
 
 # RUN TESTS
-docker exec -w /opt -t "$CONTAINER_NAME" /bin/bash -c "service mariadb start && service rsync start && pip install .[tests] && pytest -s"
+docker exec -w /opt -t "$CONTAINER_NAME" /bin/bash -c "service mariadb start && service rsync start && pip install .[tests] && pytest -s --cov=./bashckup --cov-report=term"
 TEST_RESULTS=$?
 
 # AFTER TESTS
-#docker container rm --force "$CONTAINER_NAME"
+docker container rm --force "$CONTAINER_NAME"
 cd "$OLD_PWD"
 
 # EXIT
