@@ -1,10 +1,8 @@
 import locale
 import logging
 import os
-import shutil
 from pathlib import Path
 
-from _pytest.fixtures import fixture
 from assertpy import assert_that
 from freezegun import freeze_time
 
@@ -15,6 +13,10 @@ tests_path = current_path / '..' / '..'
 conf_path = tests_path / 'resources' / 'confs'
 locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
 
+"""
+Depends on TAR
+"""
+
 
 # FIXME this test has to be rewritten
 @freeze_time('2023-07-10 15:02:10')
